@@ -9,8 +9,9 @@ import pytest
 
 import pyvo as vo
 from pyvo.dal.adhoc import DatalinkResults
+from pyvo.utils import vocabularies
 
-from astropy.utils.data import get_pkg_data_contents
+from astropy.utils.data import get_pkg_data_contents, get_pkg_data_filename
 
 get_pkg_data_contents = partial(
     get_pkg_data_contents, package=__package__, encoding='binary')
@@ -79,6 +80,25 @@ def proc(mocker):
         yield matcher
 
 
+@pytest.fixture()
+def datalink_vocabulary(mocker):
+    # astropy download_file (which get_vocabluary uses) does not use
+    # requests, so we can't mock this as we can mock the others.  We
+    # replace the entire function for a while
+    dl_voc_uri = 'http://www.ivoa.net/rdf/datalink/core'
+
+    def fake_download_file(src_url, *args, **kwargs):
+        assert src_url == dl_voc_uri
+        return get_pkg_data_filename('data/datalink/datalink.desise')
+
+    real_download_file = vocabularies.download_file
+    try:
+        vocabularies.download_file = fake_download_file
+        yield
+    finally:
+        vocabularies.download_file = real_download_file
+
+
 @pytest.mark.usefixtures('ssa_datalink', 'datalink')
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W27")
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W06")
@@ -88,18 +108,18 @@ def test_datalink():
     results = vo.spectrumsearch(
         'http://example.com/ssa_datalink', (30, 30))
 
-    datalink = next(results.iter_datalinks())
+    datalinks = next(results.iter_datalinks())
 
-    row = datalink[0]
+    row = datalinks[0]
     assert row.semantics == "#progenitor"
 
-    row = datalink[1]
+    row = datalinks[1]
     assert row.semantics == "#proc"
 
-    row = datalink[2]
+    row = datalinks[2]
     assert row.semantics == "#this"
 
-    row = datalink[3]
+    row = datalinks[3]
     assert row.semantics == "#preview"
 
 
@@ -115,70 +135,59 @@ def test_datalink_batch():
     assert len([_ for _ in results.iter_datalinks()]) == 3
 
 
-# temporary hack while astropy <4.1 is still around; you can remove
-# this and its calls once that's no longer true.
-def _debytify(v):
-    if isinstance(v, bytes):
-        return v.decode("utf-8")
-    return v
-
-
-@pytest.mark.usefixtures('proc')
+@pytest.mark.usefixtures('proc', 'datalink_vocabulary')
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W27")
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W06")
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.W48")
 @pytest.mark.filterwarnings("ignore::astropy.io.votable.exceptions.E02")
 class TestSemanticsRetrieval:
     def test_access_with_string(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics("#this")]
-        assert len(res)==1
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"] for r in datalinks.bysemantics("#this")]
+        assert len(res) == 1
         assert res[0].endswith("eq010000ms/20100927.comb_avg.0001.fits.fz")
 
     def test_access_with_list(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics(["#this", "#preview-image"])]
-        assert len(res)==2
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"]
+               for r in datalinks.bysemantics(["#this", "#preview-image"])]
+        assert len(res) == 2
         assert res[0].endswith("eq010000ms/20100927.comb_avg.0001.fits.fz")
         assert res[1].endswith("20100927.comb_avg.0001.fits.fz?preview=True")
 
     def test_access_with_expansion(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics(["#this", "#preview"])]
-        assert len(res)==3
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"]
+               for r in datalinks.bysemantics(["#this", "#preview"])]
+        assert len(res) == 3
         assert res[0].endswith("eq010000ms/20100927.comb_avg.0001.fits.fz")
         assert res[1].endswith("20100927.comb_avg.0001.fits.fz?preview=True")
         assert res[2].endswith("http://dc.zah.uni-heidelberg.de/wider.dat")
 
     def test_access_without_expansion(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics(
-               ["#this", "#preview"],
-               include_narrower=False)]
-        assert len(res)==2
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"] for r in datalinks.bysemantics(
+            ["#this", "#preview"], include_narrower=False)]
+        assert len(res) == 2
         assert res[0].endswith("eq010000ms/20100927.comb_avg.0001.fits.fz")
         assert res[1].endswith("http://dc.zah.uni-heidelberg.de/wider.dat")
 
     def test_with_full_url(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics("urn:example:rdf/dlext#oracle")]
-        assert len(res)==1
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"]
+               for r in datalinks.bysemantics("urn:example:rdf/dlext#oracle")]
+        assert len(res) == 1
         assert res[0].endswith("when-will-it-be-back")
 
     def test_all_mixed(self):
-        datalink = DatalinkResults.from_result_url('http://example.com/proc')
-        res = [_debytify(r["access_url"])
-            for r in datalink.bysemantics([
-                "urn:example:rdf/dlext#oracle",
-                'http://www.ivoa.net/rdf/datalink/core#preview',
-                '#this',
-                'non-existing-term'])]
-        assert len(res)==4
+        datalinks = DatalinkResults.from_result_url('http://example.com/proc')
+        res = [r["access_url"]
+               for r in datalinks.bysemantics([
+                   "urn:example:rdf/dlext#oracle",
+                   'http://www.ivoa.net/rdf/datalink/core#preview',
+                   '#this',
+                   'non-existing-term'])]
+        assert len(res) == 4
         assert res[0].endswith("eq010000ms/20100927.comb_avg.0001.fits.fz")
         assert res[1].endswith("comb_avg.0001.fits.fz?preview=True")
         assert res[2].endswith("http://dc.zah.uni-heidelberg.de/wider.dat")
