@@ -1,9 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import six
-
 from astropy.utils.collections import HomogeneousList
 from astropy.utils.misc import indent
 
@@ -14,7 +9,7 @@ from ...utils.xml.elements import (
 from . import voresource as vr
 from .exceptions import (
     W05, W06, W19, W20, W21, W22, W23, W24, W25, W26, W27, W28, W29, W30, W31,
-    E06, E08, E09)
+    E06, E08, E09, VOSIError)
 
 __all__ = [
     "TAPCapRestriction", "TableAccess", "DataModelType", "Language", "Version",
@@ -26,7 +21,7 @@ __all__ = [
 # ELEMENT CLASSES
 class DataModelType(ContentMixin, Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(DataModelType, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         ivo_id = kwargs.get('ivo-id', None)
         if ivo_id is None:
@@ -57,12 +52,12 @@ class DataModelType(ContentMixin, Element):
 
 class OutputFormat(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(OutputFormat, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         ivo_id = kwargs.get('ivo-id')
 
         self.mime = None
-        self._aliases = HomogeneousList(six.text_type)
+        self._aliases = HomogeneousList(str)
         self.ivo_id = ivo_id
 
     def __repr__(self):
@@ -96,7 +91,7 @@ class OutputFormat(Element):
 
 class UploadMethod(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(UploadMethod, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         ivo_id = kwargs.get('ivo-id')
         self.ivo_id = ivo_id
@@ -124,7 +119,7 @@ class UploadMethod(Element):
 
 class TimeLimits(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(TimeLimits, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         self._default = None
         self._hard = None
@@ -152,7 +147,7 @@ class TimeLimits(Element):
 
 class LanguageFeature(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(LanguageFeature, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         self.form = None
         self.description = None
@@ -174,7 +169,7 @@ class LanguageFeature(Element):
         self._description = description
 
     def parse(self, iterator, config):
-        super(LanguageFeature, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         if not self.form:
             vo_raise(E09, self._element_name, config=config, pos=self._pos)
@@ -205,7 +200,7 @@ class LanguageFeatureList(Element, HomogeneousList):
 
 class Version(ContentMixin, Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(Version, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         ivo_id = kwargs.get('ivo-id')
         self.ivo_id = ivo_id
@@ -226,7 +221,7 @@ class Version(ContentMixin, Element):
 
 class Language(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(Language, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         self.name = None
         self._versions = HomogeneousList(Version)
@@ -255,6 +250,82 @@ class Language(Element):
 
             print()
 
+    def get_feature_list(self, ivoid):
+        """
+        returns a list of features groupd with the features id ivoid.
+
+        Parameters
+        ----------
+        ivoid : the ivoid of a TAPRegExt feature list.  It is compared
+            case-insensitively against the service's ivoids.
+
+        Returns
+        -------
+        A (possibly empty) list of `~pyvo.io.vosi.tapregext.LanguageFeature` elements
+        """
+        ivoid = ivoid.lower()
+        for features in self.languagefeaturelists:
+            if features.type.lower() == ivoid:
+                return features
+        return []
+
+    def get_feature(self, ivoid, form):
+        """
+        returns the `~pyvo.io.vosi.tapregext.LanguageFeature` with ivoid and form if present.
+
+        We return None rather than raising an error because we expect
+        the normal pattern of usage here will be "if feature is present",
+        and with None-s this is simpler to write than with exceptions.
+
+        Since it's hard to predict the form of UDFs, for those rather
+        use the get_udf method.
+
+        ivoid (regrettably) has to be compared case-insensitively;
+        form is compared case-sensitively.
+
+        Parameters
+        ----------
+        ivoid : str
+            The IVOA identifier of the feature group the form is in
+        form : str
+            The form of the feature requested
+
+        Returns
+        -------
+        A `~pyvo.io.vosi.tapregext.LanguageFeature` or None.
+        """
+        for feature in self.get_feature_list(ivoid):
+            if feature.form == form:
+                return feature
+
+        return None
+
+    def get_udf(self, function_name):
+        """
+        returns a `~pyvo.io.vosi.tapregext.LanguageFeature` corresponding to an ADQL user defined
+        function on the server, on None if the UDF is not available.
+
+        This is a bit heuristic in that it tries to parse the form, which
+        is specified only so-so.
+
+        Parameters
+        ----------
+        function_name : str
+            A function name.  This is matched against the server's function
+            names case-insensitively, as guided by ADQL's case insensitivity.
+
+        Returns:
+            A `~pyvo.io.vosi.tapregext.LanguageFeature` instance or None.
+        """
+        function_name = function_name.lower()
+        for udf in self.get_feature_list(
+                "ivo://ivoa.net/std/TAPRegExt#features-udf"):
+            this_name = udf.form.split("(")[0].strip()
+            if this_name.lower() == function_name:
+                return udf
+
+        return None
+
     @xmlelement(plain=True, multiple_exc=W05)
     def name(self):
         return self._name
@@ -280,7 +351,7 @@ class Language(Element):
         return self._languagefeaturelists
 
     def parse(self, iterator, config):
-        super(Language, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         if not self.name:
             vo_raise(E06, self._element_name, config=config, pos=self._pos)
@@ -291,7 +362,7 @@ class Language(Element):
 
 class DataLimit(ContentMixin, Element):
     def __init__(self, unit=None, config=None, pos=None, **kwargs):
-        super(DataLimit, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         self.unit = unit
 
@@ -312,7 +383,7 @@ class DataLimit(ContentMixin, Element):
         self._content = int(content)
 
     def parse(self, iterator, config):
-        super(DataLimit, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         if self.unit not in ('byte', 'row'):
             warn_or_raise(W31, W31, config=config, pos=self._pos)
@@ -320,7 +391,7 @@ class DataLimit(ContentMixin, Element):
 
 class DataLimits(Element):
     def __init__(self, config=None, pos=None, **kwargs):
-        super(DataLimits, self).__init__(config=config, pos=pos, **kwargs)
+        super().__init__(config=config, pos=pos, **kwargs)
 
         self.default = None
         self.hard = None
@@ -358,14 +429,14 @@ class TAPCapRestriction(vr.Capability):
         if standardID != 'ivo://ivoa.net/std/TAP':
             warn_or_raise(W19, W19, config=config, pos=pos)
 
-        super(TAPCapRestriction, self).__init__(
+        super().__init__(
             config, pos, _name, standardID='ivo://ivoa.net/std/TAP', **kwargs)
 
 
 @vr.Capability.register_xsi_type('tr:TableAccess')
 class TableAccess(TAPCapRestriction):
     def __init__(self, config=None, pos=None, _name='capability', **kwargs):
-        super(TableAccess, self).__init__(config, pos, _name, **kwargs)
+        super().__init__(config, pos, _name, **kwargs)
 
         self._datamodels = HomogeneousList(DataModelType)
         self._languages = HomogeneousList(Language)
@@ -380,7 +451,7 @@ class TableAccess(TAPCapRestriction):
         """
         Prints out a human readable description
         """
-        super(TableAccess, self).describe()
+        super().describe()
 
         for datamodel in self.datamodels:
             datamodel.describe()
@@ -426,6 +497,19 @@ class TableAccess(TAPCapRestriction):
                 self.uploadlimit.hard.content, self.uploadlimit.hard.unit)))
             print()
 
+    def get_adql(self):
+        """
+        returns the (first) ADQL language element on this service.
+
+        ADQL support is mandatory for IVOA TAP, so in general you can
+        rely on this being present.
+        """
+        for lang in self.languages:
+            if lang.name == "ADQL":
+                return lang
+        raise VOSIError(
+            "Invalid TAP service: Does not declare an ADQL language")
+
     @xmlelement(name='dataModel', cls=DataModelType)
     def datamodels(self):
         """Identifier of IVOA-approved data model supported by the service."""
@@ -487,7 +571,7 @@ class TableAccess(TAPCapRestriction):
         self._uploadlimit = uploadlimit
 
     def parse(self, iterator, config):
-        super(TableAccess, self).parse(iterator, config)
+        super().parse(iterator, config)
 
         if not self.languages:
             warn_or_raise(W20, W20, config=config, pos=self._pos)
